@@ -73,6 +73,7 @@ mod actual {
             }],
             demand: if job.demand != 0 { Some(vec![job.demand.abs()]) } else { None },
             tag: None,
+            order: None,
         };
 
         let get_tasks = |jobs: &Vec<&CsvJob>, filter: Box<dyn Fn(&CsvJob) -> bool>| {
@@ -97,7 +98,6 @@ mod actual {
                 deliveries: get_tasks(&tasks, Box::new(|j| j.demand < 0)),
                 replacements: None,
                 services: get_tasks(&tasks, Box::new(|j| j.demand == 0)),
-                order: None,
                 skills: None,
                 value: None,
             })
@@ -114,7 +114,7 @@ mod actual {
 
                 VehicleType {
                     type_id: vehicle.id.clone(),
-                    vehicle_ids: (1..vehicle.amount).map(|seq| format!("{}_{}", vehicle.profile, seq)).collect(),
+                    vehicle_ids: (1..=vehicle.amount).map(|seq| format!("{}_{}", vehicle.profile, seq)).collect(),
                     profile: VehicleProfile { matrix: vehicle.profile, scale: None },
                     costs: VehicleCosts { fixed: Some(25.), distance: 0.0002, time: 0.005 },
                     shifts: vec![VehicleShift {
